@@ -273,6 +273,14 @@ or simply::
 
     [experimental]
     evolution=all
+
+To prevent users from creating content divergence, a check is performed by
+default on the revisions being rewritten, and the operation is aborted if it
+creates divergence. If users want to allow creating content divergent
+changesets, this check can be turned off by setting the following config::
+
+    [experimental]
+    evolution.allowdivergence=True
 """
 
 import sys
