@@ -1341,7 +1341,10 @@ def touchnodes(ui, repo, revs, displayer, **opts):
     _(b'[OPTION]... [-r] REV'),
     **compat.helpcategorykwargs('CATEGORY_CHANGE_MANAGEMENT'))
 def cmdpick(ui, repo, *revs, **opts):
-    """move a commit on the top of working directory parent and updates to it."""
+    """move a commit onto the working directory parent and update to it.
+
+    If there is an active topic, it will be used for the resulting changeset.
+    """
 
     cont = opts.get('continue')
     abort = opts.get('abort')
