@@ -300,7 +300,7 @@ def _pickresolutionparent(ui, repo, divergent, other, base, evolvestate):
         ui.write_err(hint)
         return (False, b".")
 
-    if not (divergent.mutable() and other.mutable()):
+    if not divergent.mutable():
         # Public divergence: we keep public one to local side while merging
         # When public branch is behind to the mutable branch, for now we
         # relocate mutable cset to public one's side in every case.
@@ -310,9 +310,8 @@ def _pickresolutionparent(ui, repo, divergent, other, base, evolvestate):
         #
         # Otherwise, we are going to rebase the "behind" branch up to the new
         # brancmap level.
-        publicdiv = divergent if other.mutable() else other
-        resolutionparent = publicdiv.p1().rev()
-        evolvestate[b'public-divergent'] = publicdiv.node()
+        resolutionparent = divergent.p1().rev()
+        evolvestate[b'public-divergent'] = divergent.node()
         return (True, resolutionparent)
 
     otherp1 = succsotherp1 = other.p1().rev()
@@ -447,10 +446,12 @@ def _solvedivergent(ui, repo, divergent, evolvestate, display, dryrun=False,
         ui.write_err(msg)
         return (False, b".")
     other = others[0]
+    evolvestate[b'orig-divergent'] = divergent.node()
+    if not other.mutable():
+        divergent, other = other, divergent
     evolvestate[b'divergent'] = divergent.node()
     evolvestate[b'other-divergent'] = other.node()
     evolvestate[b'base'] = base.node()
-    evolvestate[b'orig-divergent'] = divergent.node()
 
     # sometimes we will relocate a node in case of different parents and we can
     # encounter conflicts after relocation is done while solving
@@ -531,10 +532,7 @@ def _solvedivergent(ui, repo, divergent, evolvestate, display, dryrun=False,
         evolvestate[b'other-divergent'] = newother
         other = repo[newother]
 
-    localside, otherside = divergent, other
-    if not otherside.mutable():
-        localside, otherside = other, divergent
-    _mergecontentdivergents(repo, progresscb, localside, otherside, base,
+    _mergecontentdivergents(repo, progresscb, divergent, other, base,
                             evolvestate)
     res, newnode = _completecontentdivergent(ui, repo, progresscb, divergent,
                                              other, base, evolvestate)
@@ -555,7 +553,7 @@ def _solvedivergent(ui, repo, divergent, evolvestate, display, dryrun=False,
         if newnode == publicdiv.node():
             # case 2)
             pubstr = bytes(publicdiv)
-            othstr = bytes(otherside)
+            othstr = bytes(other)
             msg = _(b'content divergence resolution between %s '
                     b'(public) and %s has same content as %s, '
                     b'discarding %s\n')
@@ -575,7 +573,7 @@ def _mergecontentdivergents(repo, progresscb, local, other, base,
                      local)
         compat.update(local)
     # merging the two content-divergent changesets
-    repo.ui.note(_(b"merging \"other\" %s changeset '%s'\n") %
+    repo.ui.note(_(b"merging \"other\" %s changeset %s\n") %
                  (TROUBLES['CONTENTDIVERGENT'], other))
     if progresscb:
         progresscb()
@@ -652,9 +650,6 @@ def _completecontentdivergent(ui, repo, progresscb, divergent, other,
         else:
             date = max(divergent.date(), other.date())
 
-    localside, otherside = divergent, other
-    if not otherside.mutable():
-        localside, otherside = other, divergent
     # We really want a new commit in order to avoid obsmarker cycles (otherwise
     # divergence resolutions done in separate repos may create markers in the
     # opposite directions). For that reason, we set ui.allowemptycommit and
@@ -664,8 +659,8 @@ def _completecontentdivergent(ui, repo, progresscb, divergent, other,
         {(b'ui', b'allowemptycommit'): b'true'}, b'evolve'
     ):
         extra = {
-            b'divergence_source_local': localside.hex(),
-            b'divergence_source_other': otherside.hex()
+            b'divergence_source_local': divergent.hex(),
+            b'divergence_source_other': other.hex()
         }
         newnode = repo.commit(text=desc, user=user, date=date, extra=extra)
     new = repo[newnode]
@@ -1118,8 +1113,8 @@ def _selectrevs(repo, allopt, revopt, anyopt, targetcat):
     return revs
 
 def _dedupedivergents(repo, revs):
-    """Dedupe the divergents revs in revs to get one from each group with the
-    lowest revision numbers
+    """Dedupe the divergents revs in revs to get one from each group which
+    will be used as p1 while merging the divergent csets
     """
     repo = repo.unfiltered()
     res = set()
@@ -1131,10 +1126,36 @@ def _dedupedivergents(repo, revs):
         divergent = repo[rev]
         base, others = divergentdata(divergent)
         othersrevs = [o.rev() for o in others]
-        res.add(min([divergent.rev()] + othersrevs))
-        discarded.update(othersrevs)
+        all_divergents = othersrevs + [divergent.rev()]
+        all_divergents = _sorted_divergents(repo, all_divergents)
+        res.update(all_divergents[:1])
+        discarded.update(all_divergents[1:])
     return res
 
+def _sorted_divergents(repo, divergent_revs):
+    """Sort divergent_revs by latest evolution date, from newest to oldest.
+
+    Fall back to rev number, but in ascending order, for historical reasons.
+    """
+    ledmap = {
+        # For purpose of comparing, from `led` which is (unixtime, offset)
+        # we only need `unixtime`.
+        rev: latest_evolution_date(repo, repo[rev])[0]
+        for rev in divergent_revs
+    }
+    # Sorting by negating the `rev` in key func, to fallback to the old way
+    # of selecting revision, in case when `led` is same while comparing.
+    # Old way: was to select the one with minimum revision number
+    return sorted(divergent_revs, key=lambda rev: (-ledmap[rev], rev))
+
+def latest_evolution_date(repo, ctx):
+    """Return latest evolution date of `ctx`"""
+    node = ctx.node()
+    nodes = list(obsutil.closestpredecessors(repo, node))
+    nodes.append(node)
+    markers = obsutil.getmarkers(repo, nodes=nodes, exclusive=True)
+    return max(m.date() for m in markers)
+
 def divergentdata(ctx):
     """return base, other part of a conflict
 
@@ -1447,28 +1468,6 @@ def _checkevolveopts(repo, opts):
         if opts['all']:
             raise error.Abort(_(b'cannot specify both "--rev" and "--all"'))
 
-    # Backward compatibility
-    if opts['unstable']:
-        msg = (b"'evolve --unstable' is deprecated, "
-               b"use 'evolve --orphan'")
-        repo.ui.deprecwarn(msg, b'4.4')
-
-        opts['orphan'] = opts['divergent']
-
-    if opts['divergent']:
-        msg = (b"'evolve --divergent' is deprecated, "
-               b"use 'evolve --content-divergent'")
-        repo.ui.deprecwarn(msg, b'4.4')
-
-        opts['content_divergent'] = opts['divergent']
-
-    if opts['bumped']:
-        msg = (b"'evolve --bumped' is deprecated, "
-               b"use 'evolve --phase-divergent'")
-        repo.ui.deprecwarn(msg, b'4.4')
-
-        opts['phase_divergent'] = opts['bumped']
-
     return opts
 
 def _cleanup(ui, repo, startnode, shouldupdate, headnode):
@@ -1529,11 +1528,8 @@ def divergentsets(repo, ctx):
       _(b'also consider troubled changesets unrelated to current working '
         b'directory')),
      (b'r', b'rev', [], _(b'solves troubles of these revisions'), _(b'REV')),
-     (b'', b'bumped', False, _(b'solves only bumped changesets (DEPRECATED)')),
      (b'', b'phase-divergent', False, _(b'solves only phase-divergent changesets')),
-     (b'', b'divergent', False, _(b'solves only divergent changesets (DEPRECATED)')),
      (b'', b'content-divergent', False, _(b'solves only content-divergent changesets')),
-     (b'', b'unstable', False, _(b'solves only unstable changesets (DEPRECATED)')),
      (b'', b'orphan', False, _(b'solves only orphan changesets (default)')),
      (b'a', b'all', None, _(b'evolve all troubled changesets related to the current'
                             b' working directory and its descendants (default)')),
@@ -1740,11 +1736,12 @@ def _performevolve(ui, repo, **opts):
         seen = 1
         showprogress = allopt or revopt
         count = len(revs)
+        if showprogress:
+            progress = repo.ui.makeprogress(_(b'evolve'), _(b'changesets'), count)
 
         def progresscb():
             if showprogress:
-                compat.progress(ui, _(b'evolve'), seen, unit=_(b'changesets'),
-                                total=count)
+                progress.update(seen)
 
         # Order the revisions
         revs = _orderrevs(repo, revs)
@@ -1771,7 +1768,7 @@ def _performevolve(ui, repo, **opts):
                 seen += 1
 
         if showprogress:
-            compat.progress(ui, _(b'evolve'), None)
+            progress.complete()
 
     _cleanup(ui, repo, startnode, shouldupdate, headnode)
 
@@ -2001,10 +1998,10 @@ def continueevolve(ui, repo, evolvestate):
     # Progress handling
     seen = 1
     count = len(evolvestate[b'revs'])
+    progress = repo.ui.makeprogress(_(b'evolve'), _(b'changesets'), count)
 
     def progresscb():
-        compat.progress(ui, _(b'evolve'), seen, unit=_(b'changesets'),
-                        total=count)
+        progress.update(seen)
 
     headnode = None
     category = evolvestate[b'category']
@@ -2037,6 +2034,7 @@ def continueevolve(ui, repo, evolvestate):
                 else:
                     evolvestate[b'skippedrevs'].append(curctx.node())
             seen += 1
+    progress.complete()
     return headnode
 
 def _continuecontentdivergent(ui, repo, evolvestate, progresscb):
@@ -2075,10 +2073,7 @@ def _continuecontentdivergent(ui, repo, evolvestate, progresscb):
                 evolvestate[b'other-divergent'] = newother
                 other = repo[newother]
             # continue the resolution by merging the content-divergent csets
-            localside, otherside = divergent, other
-            if not otherside.mutable():
-                localside, otherside = other, divergent
-            _mergecontentdivergents(repo, progresscb, localside, otherside,
+            _mergecontentdivergents(repo, progresscb, divergent, other,
                                     base, evolvestate)
 
         if evolvestate[b'relocating-other']:
@@ -2093,10 +2088,7 @@ def _continuecontentdivergent(ui, repo, evolvestate, progresscb):
             evolvestate[b'other-divergent'] = newother
             other = repo[newother]
             # continue the resolution by merging the content-divergent csets
-            localside, otherside = divergent, other
-            if not otherside.mutable():
-                localside, otherside = other, divergent
-            _mergecontentdivergents(repo, progresscb, localside, otherside,
+            _mergecontentdivergents(repo, progresscb, divergent, other,
                                     base, evolvestate)
 
         res, newnode = _completecontentdivergent(ui, repo, progresscb,
