@@ -137,7 +137,7 @@ class dualsourcecache(object):
         # /!\ IMPORTANT /!\
         # You must overide this method to actually
         if reset:
-            self._cachekey = self.emptykey if reset else None
+            self._cachekey = self.emptykey
         else:
             self._cachekey = None
 
@@ -195,7 +195,7 @@ class dualsourcecache(object):
         # update the key from the new data
         key = list(self._cachekey)
         if revs:
-            key[0] = len(cl) - 1
+            key[0] = cl.tiprev()
             key[1] = cl.node(key[0])
         if obsmarkers:
             key[2] += len(obsmarkers)
@@ -213,7 +213,7 @@ class dualsourcecache(object):
         ### Is the cache valid ?
         keytiprev, keytipnode, keyobslength, keyobssize, keyobskey = key
         # check for changelog strip
-        tiprev = len(changelog) - 1
+        tiprev = changelog.tiprev()
         if (tiprev < keytiprev
                 or changelog.node(keytiprev) != keytipnode):
             return None
@@ -251,7 +251,7 @@ class dualsourcecache(object):
             reset = True
             key = self.emptykey
             obssize, obskey = obsstore.cachekey()
-            tiprev = len(cl) - 1
+            tiprev = cl.tiprev()
         else:
             tiprev, obssize, obskey = status
 
