@@ -28,7 +28,6 @@ from mercurial import (
 from mercurial.utils.stringutil import forcebytestr
 
 from . import (
-    compat,
     exthelper,
     genericcaches,
     stablerange,
@@ -92,6 +91,7 @@ class stablerangeondiskbase(stablerange.stablerangecached,
         initial_time = progress_last = time.time()
         warned_long = False
         heapify(rangeheap)
+        progress = ui.makeprogress(_(b"filling stablerange cache"), _(b"changesets"), total)
         while rangeheap:
             rangeid = heappop(rangeheap)
             if rangeid in original:
@@ -103,8 +103,7 @@ class stablerangeondiskbase(stablerange.stablerangecached,
                         warned_long = True
                     if (1 < progress_each) and (0.1 < progress_new - progress_last):
                         progress_each /= 10
-                    compat.progress(ui, _(b"filling stablerange cache"), seen,
-                                    total=total, unit=_(b"changesets"))
+                    progress.update(seen)
                     progress_last = progress_new
                 seen += 1
                 original.remove(rangeid) # might have been added from other source
@@ -113,7 +112,7 @@ class stablerangeondiskbase(stablerange.stablerangecached,
                 for sub in self.subranges(repo, rangeid):
                     if self._getsub(sub) is None:
                         heappush(rangeheap, sub)
-        compat.progress(ui, _(b"filling stablerange cache"), None, total=total)
+        progress.complete()
 
     def clear(self, reset=False):
         super(stablerangeondiskbase, self).clear()
