@@ -67,10 +67,12 @@ def shouldwarmcache(repo, tr):
     return True
 
 class MultipleSuccessorsError(RuntimeError):
-    """Exception raised by _singlesuccessor when multiple successor sets exists
+    """Exception raised by _singlesuccessor() when multiple successor sets exists
 
-    The object contains the list of successorssets in its 'successorssets'
-    attribute to call to easily recover.
+    Attributes:
+        successorssets    the list of successorssets to call to easily recover
+        divergenceflag    indicate that changeset has divergent rewriting
+        splitflag         indicate that changeset was split
     """
 
     def __init__(self, successorssets):
