@@ -167,8 +167,12 @@ class _topiccache(branchmap.branchcache): # combine me with branchmap.branchcach
         else:
             # hg <= 4.9 (624d6683c705+b137a6793c51)
             _entries = self
-        new = self.__class__(_entries, self.tipnode, self.tiprev,
-                             self.filteredhash, self._closednodes)
+        args = (_entries, self.tipnode, self.tiprev, self.filteredhash,
+                self._closednodes)
+        if util.safehasattr(self, '_repo'):
+            # hg <= 5.7 (6266d19556ad)
+            args = (self._repo,) + args
+        new = self.__class__(*args)
         new.phaseshash = self.phaseshash
         return new
 
