@@ -231,9 +231,9 @@ colortable = {b'topic.active': b'green',
               b'log.topic': b'green_background',
               }
 
-__version__ = b'0.23.0'
+__version__ = b'0.23.1'
 
-testedwith = b'4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8 5.9'
+testedwith = b'4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8 5.9 6.0'
 minimumhgversion = b'4.7'
 buglink = b'https://bz.mercurial-scm.org/'
 
